YARP 2.2.2 (2008-11-20)                                                {#v2_2_2}
=======================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.2.1...v2.2.2`):

```
   102	Paul Fitzpatrick <paulfitz@alum.mit.edu>
    35	YARP Developers <yarp0-devel@lists.sourceforge.net>
    18	Lorenzo Natale <lorenzo.natale@iit.it>
     9	Giacomo Spigler <spiglerg@gmail.com>
     5	Alessandro Scalzo <alessandro.scalzo@iit.it>
     2	Giorgio Metta <giorgio.metta@iit.it>
```
